﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Shapes;
using System.Windows.Media;
using System.Windows.Documents;
using System.Windows.Controls.Primitives;


namespace Train
{
    public class SimpleCircleAdorner : Adorner
    {
        // Be sure to call the base class constructor.
        public SimpleCircleAdorner(Path adornedElement)
            : base(adornedElement)
        {
        }

        // A common way to implement an adorner's rendering behavior is to override the OnRender
        // method, which is called by the layout system as part of a rendering pass.
        protected override void OnRender(DrawingContext drawingContext)
        {
            // Rect adornedElementRect = new Rect(this.AdornedElement.DesiredSize);
            Rect adornedElementRect = ((Path)this.AdornedElement).Data.Bounds;

            // Some arbitrary drawing implements.
            SolidColorBrush renderBrush = new SolidColorBrush(Colors.GreenYellow);
            renderBrush.Opacity = 0.2;
            Pen renderPen = new Pen(new SolidColorBrush(Colors.Navy), 1.5);
            double renderRadius = 3.0;

            // Draw a circle at each corner.
            drawingContext.DrawEllipse(renderBrush, renderPen, adornedElementRect.TopLeft, renderRadius, renderRadius);
            drawingContext.DrawEllipse(renderBrush, renderPen, adornedElementRect.TopRight, renderRadius, renderRadius);
            drawingContext.DrawEllipse(renderBrush, renderPen, adornedElementRect.BottomLeft, renderRadius, renderRadius);
            drawingContext.DrawEllipse(renderBrush, renderPen, adornedElementRect.BottomRight, renderRadius, renderRadius);
        }
    }
    public enum GraficState { grfNormal, grfDraw, grfSelect};
    public enum ObjectTyp { MyLine, MyEllipse };
    public class Graphic2D
    {
        private AdornerLayer myAdornerLayer;
        private Canvas canvas;
        public GraficState State { get; set; }
        public Graphic2D(Canvas Canvas)
        {
            canvas = Canvas;
        }
        
        

        public void CreateNewLine(Point StartPoint, Point EndPoint)
        {
            ContentControl c = new ContentControl();
            c.Width =  Math.Abs(EndPoint.X - StartPoint.X);
            c.Height = Math.Abs(EndPoint.Y - StartPoint.Y);
            Line l=new Line();
            if (StartPoint.X < EndPoint.X)
            {
                l.X1 = 0;
                l.X2 = c.Width;
            }
            else
            {
                l.X1 = c.Width;
                l.X2 = 0;
            }

            if (StartPoint.Y < EndPoint.Y)
            {

                l.Y1 = 0;
                l.Y2 = c.Height;
            }
            else
            {
                l.Y1 = c.Height;
                l.Y2 = 0;
            }
            l.StrokeThickness=1;
            l.Stroke=Brushes.Black;
            c.Content=l;
            double startPointX = Math.Min(StartPoint.X, EndPoint.X);
            double startPointY = Math.Min(StartPoint.Y, EndPoint.Y);
            Canvas.SetLeft(c, startPointX);
            Canvas.SetTop(c, startPointY);
            canvas.Children.Add(c);
        }
        public void CreateNewEllipse(Point CenterPoint, double RadiusX, double RadiusY)
        {
            //Path p = new Path();
            //p.Name = "Ellipse";
            //p.Stroke = System.Windows.Media.Brushes.Black;
            //p.StrokeThickness = 1;
            //p.HorizontalAlignment = HorizontalAlignment.Left;
            //p.VerticalAlignment = VerticalAlignment.Center;
            //EllipseGeometry e = new EllipseGeometry(CenterPoint, RadiusX, RadiusY);
            //p.Data = e;
            //canvas.Children.Add(p);
        }
        public void DeleteLastElement()
        {
             canvas.Children.RemoveAt(canvas.Children.Count - 1);
        }
        public void DeselectAll()
        {
            if (myAdornerLayer != null)
            {
                foreach (UIElement element in canvas.Children)
                {
                    Adorner[] toRemoveArray = myAdornerLayer.GetAdorners(element);
                    Adorner toRemove;
                    if (toRemoveArray != null)
                    {
                        toRemove = toRemoveArray[0];
                        myAdornerLayer.Remove(toRemove);
                    }
                }
            }
        }
        public Path HitTest(Point MousPoint)
        {
            HitTestResult htr = VisualTreeHelper.HitTest(canvas, MousPoint);
            try
            {
                Path path = (Path)htr.VisualHit;
                myAdornerLayer = AdornerLayer.GetAdornerLayer(path);
                myAdornerLayer.Add(new SimpleCircleAdorner(path));
                State = GraficState.grfSelect;
                return path;
            }
            catch
            {
                return null;
            }
        }
    }
}
